package controllers

import (
	"crypto/tls"
	"devops/dto"
	"devops/utils"
	"encoding/json"
	"github.com/astaxie/beego"
	"io/ioutil"
	"net/http"
	"net/url"
	"strings"
	"time"
)

// Operations about job
type JobController struct {
	beego.Controller
}

// URLMapping ...
func (c *JobController) URLMapping() {
	c.Mapping("getJobList", c.GetJobList)
	c.Mapping("createPipelineJob", c.CreatePipelineJob)
	c.Mapping("startRunPipelineJob", c.StartRunPipelineJob)
	c.Mapping("deletePipelineJob", c.DeletePipelineJob)
}

// GetJobList ...
// @Title GetJobList
// @Description get JobList
// @Param	lang		query 	string	true	"api result language type"
// @Param	body		body 	dto.GetPageListBaseRequestDto	true	""
// @Success 200 {object} dto.GetPageListBaseResponseDto
// @Failure 300 {object} dto.BaseResponseDto
// @router /getJobList [post]
func (c *JobController) GetJobList() {
	lang := c.GetString("lang")
	infoLogger.Println("语言: ", lang)
	var requestDto dto.GetPageListBaseRequestDto
	var errorResponseDto = dto.BaseResponseDto{300, utils.GetI18nLang(lang, "sysError")}
	var successResponseDto = dto.GetPageListBaseResponseDto{}
	if err := json.Unmarshal(c.Ctx.Input.RequestBody, &requestDto); err != nil {
		errorLogger.Println(err)
		errorResponseDto.Message = utils.GetI18nLang(lang, "requestParamIncorrectFormat")
		c.Data["json"] = errorResponseDto
		c.ServeJSON()
		return
	}
	infoLogger.Println("获取所有job请求参数: ", requestDto)

	pageIndex := requestDto.PageIndex
	pageSize := requestDto.PageSize
	if pageIndex < 0 {
		errorLogger.Println("页码必须大于等于0")
		errorResponseDto.Message = utils.GetI18nLang(lang, "pageIndexRange")
		c.Data["json"] = errorResponseDto
		c.ServeJSON()
		return
	}
	if pageSize <= 0 {
		errorLogger.Println("页大小必须大于0")
		errorResponseDto.Message = utils.GetI18nLang(lang, "pageSizeRange")
		c.Data["json"] = errorResponseDto
		c.ServeJSON()
		return
	}

	// 生成ApiToken
	//apiToken := generateApiToken()
	//apiToken := getApiToken()

	//infoLogger.Printf("调用生成ApiToken接口返回值:%s", apiToken)

	const BaseURL = "http://jenkins.poc.paas.com"
	httpClient := &http.Client{
		Transport: &http.Transport{
			TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
		},
		Timeout: 10 * time.Second,
	}

	getAllJobUrl := BaseURL + "/blue/rest/organizations/jenkins/pipelines/"
	req, _ := http.NewRequest("GET", getAllJobUrl, nil)

	getAllJobRes, err := httpClient.Do(req)
	if err != nil {
		errorLogger.Println("调用获取所有job接口失败:", err.Error())
		errorResponseDto.Message = "获取所有job失败"
		c.Data["json"] = errorResponseDto
		c.ServeJSON()
		return
	}
	getAllJobResByte, err := ioutil.ReadAll(getAllJobRes.Body)
	if err != nil {
		errorLogger.Printf("解析调用获取所有job接口返回参数失败:%s", err.Error())
		errorResponseDto.Message = "解析调用获取所有job接口返回参数失败"
		c.Data["json"] = errorResponseDto
		c.ServeJSON()
		return
	}

	var resMap []map[string]interface{}
	if err := json.Unmarshal(getAllJobResByte, &resMap); err != nil {
		errorLogger.Println("解析获取所有job接口返回数据失败:", err.Error())
		errorResponseDto.Message = "解析获取所有job接口返回数据失败"
		c.Data["json"] = errorResponseDto
		c.ServeJSON()
		return
	}

	totalRecords := len(resMap)
	infoLogger.Println("totalRecords:", totalRecords)
	totalPages := 0
	if totalRecords > 0 {
		if totalRecords <= pageIndex*pageSize {
			errorLogger.Println("页码超出最大页范围")
			errorResponseDto.Message = utils.GetI18nLang(lang, "pageIndexOutRange")
			c.Data["json"] = errorResponseDto
			c.ServeJSON()
			return
		}
		totalPages = totalRecords/pageSize + 1
		if totalRecords%pageSize == 0 {
			totalPages = totalRecords / pageSize
		}
	} else {
		if totalRecords < pageIndex*pageSize {
			errorLogger.Println("页码超出最大页范围")
			errorResponseDto.Message = utils.GetI18nLang(lang, "pageIndexOutRange")
			c.Data["json"] = errorResponseDto
			c.ServeJSON()
			return
		}
	}

	//默认截取到最后
	resultList := resMap[pageIndex*pageSize:]
	//最后部分大于页大小则截取最后部分的开头部分
	if totalRecords-pageIndex*pageSize >= pageSize {
		resultList = resMap[pageIndex*pageSize : (pageIndex+1)*pageSize]
	}
	result := []dto.GetJobListResponseDto{}
	for i, item := range resultList {
		infoLogger.Printf("-----------第%d个job---------------", i+1)
		jobName := item["fullName"].(string)
		infoLogger.Println("job name:", jobName)

		lastStatus := ""
		description := ""
		lastBuildUserName := ""
		endTimeStr := ""
		durationInMillisTimeStr := ""
		latestRun := item["latestRun"]
		if latestRun != nil {
			latestRunMap := latestRun.(map[string]interface{})
			lastStatus = latestRunMap["result"].(string)
			infoLogger.Println("job lastStatus:", lastStatus)
			if latestRunMap["description"] != nil {
				description = latestRunMap["description"].(string)
			}
			infoLogger.Println("job description:", description)

			causes := latestRunMap["causes"].([]interface{})
			if len(causes) > 0 {
				ca := causes[0].(map[string]interface{})
				lastBuildUserName = ca["userName"].(string)
			}
			infoLogger.Println("job lastBuildUserName:", lastBuildUserName)

			endTime := latestRunMap["endTime"].(string)
			endTimeStr = utils.ParseDate(endTime, false)
			infoLogger.Println("job endTime:", endTime, " ", endTimeStr)

			durationInMillis := int64(latestRunMap["durationInMillis"].(float64))
			durationInMillisTimeStr, _ = utils.ParseMilliSecondsDateToString(lang, durationInMillis)
			infoLogger.Println("job durationInMillis:", durationInMillis, " ", durationInMillisTimeStr)
		}

		o := dto.GetJobListResponseDto{
			jobName,
			lastStatus,
			lastBuildUserName,
			description,
			endTimeStr,
			durationInMillisTimeStr,
		}
		result = append(result, o)
	}

	successResponseDto.Status = 200
	successResponseDto.Result = result
	successResponseDto.PageInfo = dto.PageInfoBaseResponseDto{
		TotalRecords: totalRecords,
		TotalPages:   totalPages,
	}
	c.Data["json"] = successResponseDto
	c.ServeJSON()
}

// 生成ApiToke
func generateApiToken() string {
	httpClient := &http.Client{
		Transport: &http.Transport{
			TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
		},
		Timeout: 10 * time.Second,
		CheckRedirect: func(req *http.Request, via []*http.Request) error {
			return http.ErrUseLastResponse
		},
	}

	const UserName = "k2admin"
	const BaseURL = "http://jenkins.dev.k2paas.com"
	const AuthBaseURL = "https://auth.dev.k2paas.com"
	//loginUrl := BaseURL + "/j_security_check"
	reqUrl := BaseURL + "/user/" + UserName + "/descriptorByName/jenkins.security.ApiTokenProperty/generateNewToken"

	//hres, err := http.Get(BaseURL + "/loginEntry?from=" + "/user/" + UserName + "/descriptorByName/jenkins.security.ApiTokenProperty/generateNewToken")

	//commenceLoginReq, err := http.NewRequest("GET", BaseURL + "/securityRealm/commenceLogin?from=%2F", nil)
	//httpClient.CheckRedirect = func(req *http.Request, via []*http.Request) error {
	//   infoLogger.Println("Redirect")
	//   return errors.New("Redirect")
	//}

	commenceLoginRes, err := httpClient.Get(BaseURL + "/securityRealm/commenceLogin?from=%2F")
	if err != nil {
		errorLogger.Println(err)
	}
	infoLogger.Println(commenceLoginRes)
	co := commenceLoginRes.Cookies()
	infoLogger.Println(co)
	location, _ := commenceLoginRes.Location()
	infoLogger.Println(location.String())

	query := location.RawQuery
	infoLogger.Println(query)
	state := query[strings.Index(query, "state=")+6:]
	infoLogger.Println(state)
	//
	//hreqByte, err := ioutil.ReadAll(commenceLoginRes.Body)
	//if err != nil {
	//	errorLogger.Printf("解析调用登录接口返回参数失败:%s", err.Error())
	//	//errorResponseDto.Message = utils.GetI18nLang(lang,
	//	//	"getUserAllNameSpaces_parseCallInterfaceToGetUserAllNameSpacesResultFail")
	//	//c.Data["json"] = errorResponseDto
	//	//c.ServeJSON()
	//	return
	//}
	//infoLogger.Printf("调用登录接口返回值:%s", string(hreqByte))

	time.Sleep(2 * time.Second)
	stateRes, err := httpClient.Get(location.String())
	if err != nil {
		errorLogger.Println(err)
	}
	infoLogger.Println(stateRes)
	location1, _ := stateRes.Location()
	infoLogger.Println(location1.String())
	infoLogger.Println(location1.RawQuery)

	req := location1.RawQuery

	time.Sleep(2 * time.Second)
	rm := map[string]string{
		"login":    UserName,
		"password": "K2pass!!",
	}
	//map转json
	params1, _ := json.Marshal(rm)
	stateRes, err = httpClient.Post(location1.String(), "application/json", strings.NewReader(string(params1)))
	if err != nil {
		errorLogger.Println(err)

	}
	stateByte, err := ioutil.ReadAll(stateRes.Body)
	infoLogger.Println(string(stateByte))

	time.Sleep(2 * time.Second)
	approvalUrl := AuthBaseURL + "/approval?" + req
	approvalReq, _ := http.NewRequest("GET", approvalUrl, nil)
	approvalReq.Header.Set("Cache-Control", "no-cache")
	approvalReq.Header.Set("Connection", "keep-alive")
	//approvalReq.Header.Set("Referer", AuthBaseURL + "/securityRealm/finishLogin?code=hyvpsbaox2blx4b6wdeewkkqz&amp;state=" + state)
	approvalReq.Header.Set("Referer", location1.String())
	approvalReq.Header.Set("Accept", "*/*")
	approvalReq.Header.Set("Host", "auth.dev.k2paas.com")

	for _, c := range co {
		//if strings.Contains(c.Name, "JSESSIONID"){
		//	cook1 := http.Cookie{}
		//	cook1.Name = c.Name
		//	cook1.Value = c.Value
		//	approvalReq.AddCookie(&cook1)
		//	break
		//}
		infoLogger.Println(c)
		cook1 := http.Cookie{}
		cook1.Name = c.Name
		cook1.Value = c.Value
		cook1.Path = "/"
		approvalReq.AddCookie(&cook1)
	}

	infoLogger.Println(approvalReq)

	//httpClient.CheckRedirect = nil
	//httpC := &http.Client{
	//	Transport: &http.Transport{
	//		TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
	//	},
	//	Timeout: 10 * time.Second,
	//}

	//httpC.CheckRedirect = func(req *http.Request, via []*http.Request) error {
	//  infoLogger.Println("Redirect")
	//  return errors.New("Redirect")
	//}

	approvalRes, err := httpClient.Do(approvalReq)
	if err != nil {
		errorLogger.Println(err)
		//infoLogger.Println(approvalRes)
		//if approvalRes.StatusCode == http.StatusFound{
		//	infoLogger.Println(approvalRes.Location())
		//}
	}

	infoLogger.Println(approvalRes)
	//co2 := approvalRes.Cookies()
	//infoLogger.Println(co2)

	approvalByte, err := ioutil.ReadAll(approvalRes.Body)
	if err != nil {
		errorLogger.Printf("解析调用登录接口返回参数失败:%s", err.Error())
		//errorResponseDto.Message = utils.GetI18nLang(lang,
		//	"getUserAllNameSpaces_parseCallInterfaceToGetUserAllNameSpacesResultFail")
		//c.Data["json"] = errorResponseDto
		//c.ServeJSON()
		//return ""
	}
	infoLogger.Printf("调用登录接口返回值:%s", string(approvalByte))
	//
	//href := string(approvalByte)
	//href = href[strings.Index(href, `="`) + 2 :]
	//href = href[: strings.Index(href, `"`)]
	//
	//infoLogger.Println(href)

	//hrefReq, _ := http.NewRequest("GET", href, nil)
	//approvalReq.Header.Set("Cache-Control", "no-cache")
	//approvalReq.Header.Set("Connection", "keep-alive")
	//
	//for _, c := range co{
	//	if strings.Contains(c.Name, "JSESSIONID"){
	//		cook1 := http.Cookie{}
	//		cook1.Name = c.Name
	//		cook1.Value = c.Value
	//		approvalReq.AddCookie(&cook1)
	//		break
	//	}
	//}
	//infoLogger.Println(hrefReq)
	//hrefRes, err := httpClient.Do(hrefReq)
	//if err != nil{
	//	errorLogger.Println(err)
	//}
	//
	//infoLogger.Println(hrefRes)
	//
	//hrefByte, err := ioutil.ReadAll(hrefRes.Body)
	//if err != nil {
	//	errorLogger.Printf("解析调用登录接口返回参数失败:%s", err.Error())
	//	//errorResponseDto.Message = utils.GetI18nLang(lang,
	//	//	"getUserAllNameSpaces_parseCallInterfaceToGetUserAllNameSpacesResultFail")
	//	//c.Data["json"] = errorResponseDto
	//	//c.ServeJSON()
	//	//return ""
	//}
	//infoLogger.Printf("调用登录接口返回值:%s", string(hrefByte))

	//if r.MatchString(string(approvalByte)){
	//	infoLogger.Println(r.FindString(string(approvalByte)))
	//}

	//time.Sleep(2 * time.Second)

	//params := url.Values{
	//	"newTokenName": []string{UserName},
	//}
	//requestMap := map[string]string{
	//	"newTokenName": UserName,
	//}
	////map转json
	//params, _ := json.Marshal(requestMap)

	tokenPrams := "newTokenName=" + url.QueryEscape(UserName)

	tokenReq, _ := http.NewRequest("POST", reqUrl+"?"+tokenPrams, nil)
	tokenReq.Header.Set("Content-Type", "application/x-www-form-urlencoded")
	tokenReq.Header.Set("Accept", "*/*")
	tokenReq.Header.Set("Host", "auth.dev.k2paas.com")
	for _, c := range co {
		if strings.Contains(c.Name, "JSESSIONID") {
			cook1 := http.Cookie{}
			cook1.Name = c.Name
			cook1.Value = c.Value
			tokenReq.AddCookie(&cook1)
			break
		}
	}

	infoLogger.Println(tokenReq)

	res, err := httpClient.Do(tokenReq)

	if err != nil {
		errorLogger.Println(err)
	}

	infoLogger.Println(res)

	resByte, err := ioutil.ReadAll(res.Body)
	if err != nil {
		errorLogger.Printf("解析调用生成ApiToken接口返回参数失败:%s", err.Error())
		//errorResponseDto.Message = utils.GetI18nLang(lang,
		//	"getUserAllNameSpaces_parseCallInterfaceToGetUserAllNameSpacesResultFail")
		//c.Data["json"] = errorResponseDto
		//c.ServeJSON()
		//return
	}
	infoLogger.Printf("调用生成ApiToken接口返回值:%s", string(resByte))

	return ""
}

func getApiToken() string {
	httpClient := &http.Client{
		Transport: &http.Transport{
			TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
		},
		Timeout: 10 * time.Second,
		CheckRedirect: func(req *http.Request, via []*http.Request) error {
			return http.ErrUseLastResponse
		},
	}

	const UserName = "admin"
	const BaseURL = "http://jenkins.test.k2paas.com"
	loginUrl := BaseURL + "/j_security_check"
	reqUrl := BaseURL + "/user/" + UserName + "/descriptorByName/jenkins.security.ApiTokenProperty/generateNewToken"

	//hres, err := http.Get(BaseURL + "/loginEntry?from=" + "/user/" + UserName + "/descriptorByName/jenkins.security.ApiTokenProperty/generateNewToken")
	//hres, err := http.Get(BaseURL + "/loginEntry?from=%2F")
	//if err != nil{
	//	errorLogger.Println(err)
	//}
	//co := hres.Cookies()
	//infoLogger.Println(co)
	//infoLogger.Println(hres.Location())
	//
	//hreqByte, err := ioutil.ReadAll(hres.Body)
	//if err != nil {
	//	errorLogger.Printf("解析调用登录接口返回参数失败:%s", err.Error())
	//	//errorResponseDto.Message = utils.GetI18nLang(lang,
	//	//	"getUserAllNameSpaces_parseCallInterfaceToGetUserAllNameSpacesResultFail")
	//	//c.Data["json"] = errorResponseDto
	//	//c.ServeJSON()
	//	//return
	//}
	//infoLogger.Printf("调用登录接口返回值:%s", string(hreqByte))

	//rm := map[string]string{
	//	"j_username": UserName,
	//	"j_password": "K2pass!",
	//	"from": "",
	//	"Submit": "Sign in",
	//}
	////map转json
	//params1, _ := json.Marshal(rm)

	//var values = make(url.Values)
	//for k, v := range rm {
	//	values.Set(k, v)
	//}

	//loginParams := "j_username=" + url.QueryEscape(UserName) + "&j_password=" + url.QueryEscape("K2pass!!") +
	//	"&from=" + "&Submit=" + url.QueryEscape("Sign in")
	//infoLogger.Println(loginParams)
	loginParams := "j_username=admin&j_password=K2pass%21&from=&Submit=%E7%99%BB%E5%BD%95"

	req, _ := http.NewRequest("POST", loginUrl+"?"+loginParams, nil)
	//req, _ := http.NewRequest("POST", loginUrl, bytes.NewBufferString(values.Encode()))
	//loginRes, err := httpClient.Post(loginUrl, "application/x-www-form-urlencoded",
	//	strings.NewReader(string(params1)))

	req.Header.Set("Content-Type", "application/x-www-form-urlencoded")
	//req.Header.Set("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3")
	//req.Header.Set("Accept-Language", "zh-CN,zh;q=0.9")
	//req.Header.Set("User-Agent", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.100 Safari/537.36")
	//req.Header.Set("Accept-Encoding", "gzip, deflate")

	//cook1 := http.Cookie{}
	//cook1.Name = "JSESSIONID.ba2e8e90"
	//cook1.Value = "node01gbb70k4t72ek1thwvtsb15plk20823.node0"
	//req.AddCookie(&cook1)

	//for _, c := range co{
	//	if strings.Contains(c.Name, "JSESSIONID"){
	//		cook1 := http.Cookie{}
	//		cook1.Name = c.Name
	//		cook1.Value = c.Value
	//		req.AddCookie(&cook1)
	//		break
	//	}
	//}

	infoLogger.Println(req)
	//reqByte, err := ioutil.ReadAll(req.Body)
	//infoLogger.Println(string(reqByte))

	//httpClient.CheckRedirect = func(req *http.Request, via []*http.Request) error {
	//    infoLogger.Println("Redirect")
	//    return errors.New("Redirect")
	//}

	loginRes, err := httpClient.Do(req)
	if err != nil {
		errorLogger.Println(err)
		//if loginRes.StatusCode == http.StatusFound{
		//	infoLogger.Println(loginRes.Location())
		//}
	}

	infoLogger.Println(loginRes)
	cook := loginRes.Cookies()
	infoLogger.Println(cook)
	infoLogger.Println(loginRes.Location())
	reqByte, err := ioutil.ReadAll(loginRes.Body)
	if err != nil {
		errorLogger.Printf("解析调用登录接口返回参数失败:%s", err.Error())
		//errorResponseDto.Message = utils.GetI18nLang(lang,
		//	"getUserAllNameSpaces_parseCallInterfaceToGetUserAllNameSpacesResultFail")
		//c.Data["json"] = errorResponseDto
		//c.ServeJSON()
		//return
	}
	infoLogger.Printf("调用登录接口返回值:%s", string(reqByte))

	//params := url.Values{
	//	"newTokenName": []string{UserName},
	//}
	//requestMap := map[string]string{
	//	"newTokenName": UserName,
	//}
	////map转json
	//params, _ := json.Marshal(requestMap)

	tokenPrams := "newTokenName=" + url.QueryEscape(UserName)

	tokenReq, _ := http.NewRequest("POST", reqUrl+"?"+tokenPrams, nil)
	tokenReq.Header.Set("Content-Type", "application/x-www-form-urlencoded")
	//tokenReq.Header.Set("Accept", "application/json")
	//tokenReq.Header.Set("Accept-Language", "zh-CN,zh;q=0.9")
	//req.Header.Set("User-Agent", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.100 Safari/537.36")
	//req.SetBasicAuth("admin", "K2pass!")
	for _, c := range cook {
		if strings.Contains(c.Name, "JSESSIONID") {
			cook1 := http.Cookie{}
			cook1.Name = c.Name
			cook1.Value = c.Value
			tokenReq.AddCookie(&cook1)
			break
		}
	}
	//req.Response.Header.Set("Content-Type", "application/json;charset=utf-8")
	//req.Response.Header["Content-Type"] = []string{"application/json"}
	infoLogger.Println(tokenReq)
	//reqByte, err := ioutil.ReadAll(req.Body)
	//infoLogger.Println(string(reqByte))
	res, err := httpClient.Do(tokenReq)

	//
	//res, err := http.Post(reqUrl, "application/x-www-form-urlencoded; charset=UTF-8",
	//	strings.NewReader(string(params)))

	//res, err := httpClient.Post(reqUrl, "application/x-www-form-urlencoded; charset=UTF-8",
	//	strings.NewReader(tokenPrams))
	if err != nil {
		errorLogger.Println(err)
	}

	infoLogger.Println(res)

	resByte, err := ioutil.ReadAll(res.Body)
	if err != nil {
		errorLogger.Printf("解析调用生成ApiToken接口返回参数失败:%s", err.Error())
		//errorResponseDto.Message = utils.GetI18nLang(lang,
		//	"getUserAllNameSpaces_parseCallInterfaceToGetUserAllNameSpacesResultFail")
		//c.Data["json"] = errorResponseDto
		//c.ServeJSON()
		//return
	}
	infoLogger.Printf("调用生成ApiToken接口返回值:%s", string(resByte))

	return ""
}

// createPipelineJob ...
// @Title createPipelineJob
// @Description create PipelineJob
// @Param	lang		query 	string	true	"api result language type"
// @Param	body		body 	dto.CreatePipelineJobRequestDto	true	""
// @Success 200 {object} dto.BaseResponseDto
// @Failure 300 {object} dto.BaseResponseDto
// @router /createPipelineJob [post]
func (c *JobController) CreatePipelineJob() {
	lang := c.GetString("lang")
	infoLogger.Println("语言: ", lang)
	var requestDto dto.CreatePipelineJobRequestDto
	var responseDto = dto.BaseResponseDto{300, ""}
	if err := json.Unmarshal(c.Ctx.Input.RequestBody, &requestDto); err != nil {
		errorLogger.Println(err)
		responseDto.Message = utils.GetI18nLang(lang, "requestParamIncorrectFormat")
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}
	infoLogger.Println("创建job请求参数: ", requestDto)

	jobName := requestDto.JobName
	if strings.TrimSpace(jobName) == "" {
		errorLogger.Println("job名称不能为空")
		responseDto.Message = "job名称不能为空"
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}
	description := requestDto.Description
	gitBaseUrl := requestDto.GitBaseUrl
	branch := requestDto.Branch
	buildScriptPath := requestDto.BuildScriptPath
	//credentialId := requestDto.CredentialId
	listeningEvents := requestDto.ListeningEvents

	//执行创建job
	execCreatePipelineJobRes := ExecCreatePipelineJob(requestDto.JobName)
	if execCreatePipelineJobRes.Status == 300 {
		errorLogger.Printf("执行创建job:%s失败:%s", jobName, execCreatePipelineJobRes.Message)
		responseDto.Message = execCreatePipelineJobRes.Message
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}

	infoLogger.Printf("执行配置job:%s", jobName)

	params := "description=" + url.QueryEscape(description) +
		"&stapler-class-bag=true&_.daysToKeepStr=&_.numToKeepStr=&_.artifactDaysToKeepStr=" +
		"&_.artifactNumToKeepStr=&stapler-class=hudson.tasks.LogRotator&%24class=" +
		"hudson.tasks.LogRotator&_.projectUrlStr=&_.displayName=&_.gitLabConnection=&hint=" +
		"MAX_SURVIVABILITY&_.buildCount=1&_.count=1&_.durationName=second&stapler-class-bag=" +
		"true&_.upstreamProjects=&ReverseBuildTrigger.threshold=SUCCESS&_.spec=" +
		"&com-dabsquared-gitlabjenkins-GitLabPushTrigger=on&_.triggerOnPush=on" +
		"&_.triggerOpenMergeRequestOnPush=never&_.noteRegex=Jenkins+please+retry+a+build&_.ciSkip=" +
		"on&_.skipWorkInProgressMergeRequest=on&_.setBuildDescription=on&_.pendingBuildName=" +
		"&branchFilterType=All&includeBranchesSpec=&excludeBranchesSpec=&sourceBranchRegex=" +
		"&targetBranchRegex=&include=&exclude=&_.secretToken=&_.scmpoll_spec=&quiet_period=5" +
		"&_.displayNameOrNull=&_.script=&_.sandbox=on&stapler-class=" +
		"org.jenkinsci.plugins.workflow.cps.CpsFlowDefinition&%24class=" +
		"org.jenkinsci.plugins.workflow.cps.CpsFlowDefinition&stapler-class=hudson.scm.NullSCM&%24class=hudson.scm.NullSCM" +
		"&_.url=" + url.QueryEscape(gitBaseUrl) +
		"&_.credentialsId=" +
		"&_.name=&_.refspec=" +
		"&_.name=*%2F" + url.QueryEscape(branch) +
		"&stapler-class=hudson.plugins.git.browser.AssemblaWeb&%24class=" +
		"hudson.plugins.git.browser.AssemblaWeb&stapler-class=" +
		"hudson.plugins.git.browser.FisheyeGitRepositoryBrowser&%24class=" +
		"hudson.plugins.git.browser.FisheyeGitRepositoryBrowser&stapler-class=" +
		"hudson.plugins.git.browser.KilnGit&%24class=hudson.plugins.git.browser.KilnGit&stapler-class=" +
		"hudson.plugins.git.browser.TFS2013GitRepositoryBrowser&%24class=" +
		"hudson.plugins.git.browser.TFS2013GitRepositoryBrowser&stapler-class=" +
		"hudson.plugins.git.browser.BitbucketWeb&%24class=hudson.plugins.git.browser.BitbucketWeb&stapler-class=" +
		"hudson.plugins.git.browser.CGit&%24class=hudson.plugins.git.browser.CGit&stapler-class=" +
		"hudson.plugins.git.browser.GitBlitRepositoryBrowser&%24class=" +
		"hudson.plugins.git.browser.GitBlitRepositoryBrowser&stapler-class=" +
		"hudson.plugins.git.browser.GithubWeb&%24class=hudson.plugins.git.browser.GithubWeb&stapler-class=" +
		"hudson.plugins.git.browser.Gitiles&%24class=hudson.plugins.git.browser.Gitiles&stapler-class=" +
		"hudson.plugins.git.browser.GitLab&%24class=hudson.plugins.git.browser.GitLab&stapler-class=" +
		"hudson.plugins.git.browser.GitList&%24class=hudson.plugins.git.browser.GitList&stapler-class=" +
		"hudson.plugins.git.browser.GitoriousWeb&%24class=hudson.plugins.git.browser.GitoriousWeb&stapler-class=" +
		"hudson.plugins.git.browser.GitWeb&%24class=hudson.plugins.git.browser.GitWeb&stapler-class=" +
		"hudson.plugins.git.browser.GogsGit&%24class=hudson.plugins.git.browser.GogsGit&stapler-class=" +
		"hudson.plugins.git.browser.Phabricator&%24class=hudson.plugins.git.browser.Phabricator&stapler-class=" +
		"hudson.plugins.git.browser.RedmineWeb&%24class=hudson.plugins.git.browser.RedmineWeb&stapler-class=" +
		"hudson.plugins.git.browser.RhodeCode&%24class=hudson.plugins.git.browser.RhodeCode&stapler-class=" +
		"hudson.plugins.git.browser.Stash&%24class=hudson.plugins.git.browser.Stash&stapler-class=" +
		"hudson.plugins.git.browser.ViewGitWeb&%24class=hudson.plugins.git.browser.ViewGitWeb&stapler-class=" +
		"hudson.plugins.git.GitSCM&%24class=hudson.plugins.git.GitSCM&stapler-class=" +
		"hudson.plugins.mercurial.MercurialSCM&%24class=hudson.plugins.mercurial.MercurialSCM" +
		"&_.scriptPath=" + url.QueryEscape(buildScriptPath) +
		"&_.lightweight=on&stapler-class=org.jenkinsci.plugins.workflow.cps.CpsScmFlowDefinition&%24class=" +
		"org.jenkinsci.plugins.workflow.cps.CpsScmFlowDefinition&core%3Aapply=" +
		"&json=%7B%22description%22%3A+%22" + url.QueryEscape(description) +
		"%22%2C+%22properties%22%3A+%7B%22stapler-class-bag%22%3A+%22true" +
		"%22%2C+%22hudson-plugins-jira-JiraProjectProperty%22%3A+%7B%22siteName%22%3A+%22%22%7D%2C+%22" +
		"jenkins-model-BuildDiscarderProperty%22%3A+%7B%22specified%22%3A+false%2C+%22%22%3A+%220%22%2C+%22strategy" +
		"%22%3A+%7B%22daysToKeepStr%22%3A+%22%22%2C+%22numToKeepStr%22%3A+%22%22%2C+%22artifactDaysToKeepStr" +
		"%22%3A+%22%22%2C+%22artifactNumToKeepStr%22%3A+%22%22%2C+%22stapler-class%22%3A+%22" +
		"hudson.tasks.LogRotator%22%2C+%22%24class%22%3A+%22hudson.tasks.LogRotator%22%7D%7D%2C+%22" +
		"org-jenkinsci-plugins-workflow-job-properties-DisableConcurrentBuildsJobProperty%22%3A+%7B%22specified" +
		"%22%3A+false%7D%2C+%22org-jenkinsci-plugins-workflow-job-properties-DisableResumeJobProperty" +
		"%22%3A+%7B%22specified%22%3A+false%7D%2C+%22com-coravy-hudson-plugins-github-GithubProjectProperty" +
		"%22%3A+%7B%7D%2C+%22com-dabsquared-gitlabjenkins-connection-GitLabConnectionProperty%22%3A+%7B%22" +
		"gitLabConnection%22%3A+%22%22%7D%2C+%22org-jenkinsci-plugins-workflow-job-properties-DurabilityHintJobProperty" +
		"%22%3A+%7B%22specified%22%3A+false%2C+%22hint%22%3A+%22MAX_SURVIVABILITY%22%7D%2C+%22" +
		"org-jenkinsci-plugins-pipeline-modeldefinition-properties-PreserveStashesJobProperty" +
		"%22%3A+%7B%22specified%22%3A+false%2C+%22buildCount%22%3A+%221%22%7D%2C+%22" +
		"hudson-model-ParametersDefinitionProperty%22%3A+%7B%22specified%22%3A+false%7D%2C+%22" +
		"jenkins-branch-RateLimitBranchProperty%24JobPropertyImpl%22%3A+%7B%7D%2C+%22" +
		"org-jenkinsci-plugins-workflow-job-properties-PipelineTriggersJobProperty%22%3A+%7B%22" +
		"triggers%22%3A+%7B%22stapler-class-bag%22%3A+%22true%22%2C+%22" +
		"com-dabsquared-gitlabjenkins-GitLabPushTrigger%22%3A+%7B%22triggerOnPush%22%3A+true%2C+%22" +
		"triggerOnMergeRequest%22%3A+false%2C+%22triggerOnAcceptedMergeRequest%22%3A+false%2C+%22" +
		"triggerOnClosedMergeRequest%22%3A+false%2C+%22triggerOpenMergeRequestOnPush%22%3A+%22" +
		"never%22%2C+%22triggerOnApprovedMergeRequest%22%3A+false%2C+%22triggerOnNoteRequest" +
		"%22%3A+false%2C+%22noteRegex%22%3A+%22Jenkins+please+retry+a+build%22%2C+%22ciSkip" +
		"%22%3A+true%2C+%22skipWorkInProgressMergeRequest%22%3A+true%2C+%22setBuildDescription" +
		"%22%3A+true%2C+%22triggerOnPipelineEvent%22%3A+false%2C+%22pendingBuildName" +
		"%22%3A+%22%22%2C+%22cancelPendingBuildsOnUpdate%22%3A+false%2C+%22branchFilterType" +
		"%22%3A+%22All%22%2C+%22includeBranchesSpec%22%3A+%22%22%2C+%22excludeBranchesSpec" +
		"%22%3A+%22%22%2C+%22sourceBranchRegex%22%3A+%22%22%2C+%22targetBranchRegex%22%3A+%22%22%2C+%22secretToken" +
		"%22%3A+%22%22%7D%7D%7D%7D%2C+%22disable%22%3A+false%2C+%22hasCustomQuietPeriod%22%3A+false%2C+%22" +
		"quiet_period%22%3A+%225%22%2C+%22displayNameOrNull%22%3A+%22%22%2C+%22%22%3A+%221%22%2C+%22definition" +
		"%22%3A+%7B%22%22%3A+%221%22%2C+%22scm%22%3A+%7B%22userRemoteConfigs%22%3A+%7B%22" +
		"url%22%3A+%22" + url.QueryEscape(gitBaseUrl) + "%22%2C+%22" +
		"credentialsId%22%3A+%22%22%2C+%22" +
		"name%22%3A+%22%22%2C+%22refspec%22%3A+%22%22%7D%2C+%22branches%22%3A+%7B%22" +
		"name%22%3A+%22*%2F" + url.QueryEscape(branch) + "%22%7D%2C+%22%22%3A+%22auto" +
		"%22%2C+%22stapler-class%22%3A+%22hudson.plugins.git.GitSCM%22%2C+%22%24class%22%3A+%22" +
		"hudson.plugins.git.GitSCM%22%7D%2C+%22" +
		"scriptPath%22%3A+%22" + url.QueryEscape(buildScriptPath) +
		"%22%2C+%22lightweight%22%3A+true%2C+%22stapler-class%22%3A+%22org.jenkinsci.plugins.workflow.cps.CpsScmFlowDefinition" +
		"%22%2C+%22%24class%22%3A+%22org.jenkinsci.plugins.workflow.cps.CpsScmFlowDefinition" +
		"%22%7D%2C+%22core%3Aapply%22%3A+%22%22%7D&Submit=%E4%BF%9D%E5%AD%98"

	// 没有选择监听push事件
	if !listeningEvents.Push {
		params = "description=" + url.QueryEscape(description) +
			"&stapler-class-bag=true&_.daysToKeepStr=" +
			"&_.numToKeepStr=&_.artifactDaysToKeepStr=&_.artifactNumToKeepStr=" +
			"&stapler-class=hudson.tasks.LogRotator&%24class=hudson.tasks.LogRotator&_.projectUrlStr=" +
			"&_.displayName=&_.gitLabConnection=&hint=MAX_SURVIVABILITY&_.buildCount=1&_.count=1" +
			"&_.durationName=second&stapler-class-bag=true&_.upstreamProjects=" +
			"&ReverseBuildTrigger.threshold=SUCCESS&_.spec=&_.triggerOpenMergeRequestOnPush=never&_.noteRegex=" +
			"Jenkins+please+retry+a+build&_.ciSkip=on&_.skipWorkInProgressMergeRequest=on&_.setBuildDescription=on" +
			"&_.pendingBuildName=&branchFilterType=All&includeBranchesSpec=&excludeBranchesSpec=" +
			"&sourceBranchRegex=&targetBranchRegex=&include=&exclude=&_.secretToken=&_.scmpoll_spec=" +
			"&quiet_period=5&_.displayNameOrNull=&stapler-class=" +
			"org.jenkinsci.plugins.workflow.cps.CpsFlowDefinition&%24class=" +
			"org.jenkinsci.plugins.workflow.cps.CpsFlowDefinition" +
			"&_.url=" + url.QueryEscape(gitBaseUrl) +
			"&_.credentialsId=" +
			"&_.name=&_.refspec=" +
			"&_.name=*%2F" + url.QueryEscape(branch) +
			"&stapler-class=hudson.plugins.git.browser.AssemblaWeb&%24class=" +
			"hudson.plugins.git.browser.AssemblaWeb&stapler-class=" +
			"hudson.plugins.git.browser.FisheyeGitRepositoryBrowser&%24class=" +
			"hudson.plugins.git.browser.FisheyeGitRepositoryBrowser&stapler-class=" +
			"hudson.plugins.git.browser.KilnGit&%24class=hudson.plugins.git.browser.KilnGit&stapler-class=" +
			"hudson.plugins.git.browser.TFS2013GitRepositoryBrowser&%24class=" +
			"hudson.plugins.git.browser.TFS2013GitRepositoryBrowser&stapler-class=" +
			"hudson.plugins.git.browser.BitbucketWeb&%24class=hudson.plugins.git.browser.BitbucketWeb&stapler-class=" +
			"hudson.plugins.git.browser.CGit&%24class=hudson.plugins.git.browser.CGit&stapler-class=" +
			"hudson.plugins.git.browser.GitBlitRepositoryBrowser&%24class=" +
			"hudson.plugins.git.browser.GitBlitRepositoryBrowser&stapler-class=" +
			"hudson.plugins.git.browser.GithubWeb&%24class=hudson.plugins.git.browser.GithubWeb&stapler-class=" +
			"hudson.plugins.git.browser.Gitiles&%24class=hudson.plugins.git.browser.Gitiles&stapler-class=" +
			"hudson.plugins.git.browser.GitLab&%24class=hudson.plugins.git.browser.GitLab&stapler-class=" +
			"hudson.plugins.git.browser.GitList&%24class=hudson.plugins.git.browser.GitList&stapler-class=" +
			"hudson.plugins.git.browser.GitoriousWeb&%24class=hudson.plugins.git.browser.GitoriousWeb&stapler-class=" +
			"hudson.plugins.git.browser.GitWeb&%24class=hudson.plugins.git.browser.GitWeb&stapler-class=" +
			"hudson.plugins.git.browser.GogsGit&%24class=hudson.plugins.git.browser.GogsGit&stapler-class=" +
			"hudson.plugins.git.browser.Phabricator&%24class=hudson.plugins.git.browser.Phabricator&stapler-class=" +
			"hudson.plugins.git.browser.RedmineWeb&%24class=hudson.plugins.git.browser.RedmineWeb&stapler-class=" +
			"hudson.plugins.git.browser.RhodeCode&%24class=hudson.plugins.git.browser.RhodeCode&stapler-class=" +
			"hudson.plugins.git.browser.Stash&%24class=hudson.plugins.git.browser.Stash&stapler-class=" +
			"hudson.plugins.git.browser.ViewGitWeb&%24class=hudson.plugins.git.browser.ViewGitWeb&stapler-class=" +
			"hudson.plugins.git.GitSCM&%24class=hudson.plugins.git.GitSCM&stapler-class=" +
			"hudson.plugins.mercurial.MercurialSCM&%24class=hudson.plugins.mercurial.MercurialSCM" +
			"&_.scriptPath=" + url.QueryEscape(buildScriptPath) +
			"&_.lightweight=on&stapler-class=org.jenkinsci.plugins.workflow.cps.CpsScmFlowDefinition&%24class=" +
			"org.jenkinsci.plugins.workflow.cps.CpsScmFlowDefinition&core%3Aapply=" +
			"&json=%7B%22description%22%3A+%22" + url.QueryEscape(description) +
			"%22%2C+%22properties%22%3A+%7B%22stapler-class-bag%22%3A+%22true%22%2C+%22" +
			"hudson-plugins-jira-JiraProjectProperty%22%3A+%7B%22siteName%22%3A+%22%22%7D%2C+%22" +
			"jenkins-model-BuildDiscarderProperty%22%3A+%7B%22specified%22%3A+false%2C+%22%22%3A+%220%22%2C+%22" +
			"strategy%22%3A+%7B%22daysToKeepStr%22%3A+%22%22%2C+%22numToKeepStr%22%3A+%22%22%2C+%22" +
			"artifactDaysToKeepStr%22%3A+%22%22%2C+%22artifactNumToKeepStr%22%3A+%22%22%2C+%22stapler-class" +
			"%22%3A+%22hudson.tasks.LogRotator%22%2C+%22%24class%22%3A+%22" +
			"hudson.tasks.LogRotator%22%7D%7D%2C+%22" +
			"org-jenkinsci-plugins-workflow-job-properties-DisableConcurrentBuildsJobProperty%22%3A+%7B%22" +
			"specified%22%3A+false%7D%2C+%22org-jenkinsci-plugins-workflow-job-properties-DisableResumeJobProperty" +
			"%22%3A+%7B%22specified%22%3A+false%7D%2C+%22com-coravy-hudson-plugins-github-GithubProjectProperty" +
			"%22%3A+%7B%7D%2C+%22com-dabsquared-gitlabjenkins-connection-GitLabConnectionProperty%22%3A+%7B%22" +
			"gitLabConnection%22%3A+%22%22%7D%2C+%22org-jenkinsci-plugins-workflow-job-properties-DurabilityHintJobProperty" +
			"%22%3A+%7B%22specified%22%3A+false%2C+%22hint%22%3A+%22MAX_SURVIVABILITY%22%7D%2C+%22" +
			"org-jenkinsci-plugins-pipeline-modeldefinition-properties-PreserveStashesJobProperty" +
			"%22%3A+%7B%22specified%22%3A+false%2C+%22buildCount%22%3A+%221%22%7D%2C+%22" +
			"hudson-model-ParametersDefinitionProperty%22%3A+%7B%22specified%22%3A+false%7D%2C+%22" +
			"jenkins-branch-RateLimitBranchProperty%24JobPropertyImpl%22%3A+%7B%7D%2C+%22" +
			"org-jenkinsci-plugins-workflow-job-properties-PipelineTriggersJobProperty%22%3A+%7B%22" +
			"triggers%22%3A+%7B%22stapler-class-bag%22%3A+%22true%22%7D%7D%7D%2C+%22disable" +
			"%22%3A+false%2C+%22hasCustomQuietPeriod%22%3A+false%2C+%22quiet_period%22%3A+%225%22%2C+%22" +
			"displayNameOrNull%22%3A+%22%22%2C+%22%22%3A+%221%22%2C+%22definition%22%3A+%7B%22%22%3A+%220%22%2C+%22" +
			"scm%22%3A+%7B%22userRemoteConfigs%22%3A+%7B%22" +
			"url%22%3A+%22" + url.QueryEscape(gitBaseUrl) + "%22%2C+%22" +
			"credentialsId%22%3A+%22%22%2C+%22" +
			"name%22%3A+%22%22%2C+%22refspec%22%3A+%22%22%7D%2C+%22branches%22%3A+%7B%22" +
			"name%22%3A+%22*%2F" + url.QueryEscape(branch) + "%22%7D%2C+%22%22%3A+%22" +
			"auto%22%2C+%22stapler-class%22%3A+%22hudson.plugins.git.GitSCM%22%2C+%22%24class%22%3A+%22" +
			"hudson.plugins.git.GitSCM%22%7D%2C+%22" +
			"scriptPath%22%3A+%22" + url.QueryEscape(buildScriptPath) +
			"%22%2C+%22lightweight%22%3A+true%2C+%22stapler-class" +
			"%22%3A+%22org.jenkinsci.plugins.workflow.cps.CpsScmFlowDefinition%22%2C+%22%24class%22%3A+%22" +
			"org.jenkinsci.plugins.workflow.cps.CpsScmFlowDefinition%22%7D%2C+%22core%3Aapply%22%3A+%22%22%7D" +
			"&Submit=%E4%BF%9D%E5%AD%98"
	}

	const BaseUrl = "http://jenkins.poc.paas.com"
	configSubmitUrl := BaseUrl + "/job/" + jobName + "/configSubmit"

	httpClient := &http.Client{
		Transport: &http.Transport{
			TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
		},
		Timeout: 10 * time.Second,
		CheckRedirect: func(req *http.Request, via []*http.Request) error {
			return http.ErrUseLastResponse
		},
	}
	infoLogger.Println(params)
	configSubmitReq, _ := http.NewRequest("POST", configSubmitUrl, strings.NewReader(params))
	configSubmitReq.Header.Set("Content-Type", "application/x-www-form-urlencoded")

	configSubmitRes, err := httpClient.Do(configSubmitReq)
	if err != nil {
		errorLogger.Printf("执行配置job:%s失败:%s", jobName, err.Error())
		responseDto.Message = "执行配置job失败"
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}

	infoLogger.Printf("执行配置job:%s返回结果:%v", jobName, configSubmitRes.Status)
	if configSubmitRes.StatusCode != http.StatusFound {
		responseDto.Message = "执行配置job失败"
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}
	infoLogger.Printf("执行配置job:%s成功", jobName)

	responseDto.Status = 200
	responseDto.Message = "成功"
	c.Data["json"] = responseDto
	c.ServeJSON()
}

//执行创建job
func ExecCreatePipelineJob(jobName string) dto.BaseResponseDto {
	var responseDto = dto.BaseResponseDto{300, ""}
	if strings.TrimSpace(jobName) == "" {
		errorLogger.Println("job名称不能为空")
		responseDto.Message = "job名称不能为空"
		return responseDto
	}

	const BaseUrl = "http://jenkins.poc.paas.com"
	createUrl := BaseUrl + "/createItem"

	httpClient := &http.Client{
		Transport: &http.Transport{
			TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
		},
		Timeout: 10 * time.Second,
		CheckRedirect: func(req *http.Request, via []*http.Request) error {
			return http.ErrUseLastResponse
		},
	}

	paramsMap := map[string]map[string]string{
		"json": {
			"name": jobName,
			"mode": "org.jenkinsci.plugins.workflow.job.WorkflowJob",
			"from": "",
		},
	}
	paramsByte, _ := json.Marshal(paramsMap)

	paramsStr := "name=" + jobName + "&mode=org.jenkinsci.plugins.workflow.job.WorkflowJob&from=&json=" +
		url.QueryEscape(string(paramsByte))
	infoLogger.Println(paramsStr)
	req, _ := http.NewRequest("POST", createUrl+"?"+paramsStr, nil)
	req.Header.Set("Content-Type", "application/x-www-form-urlencoded")

	createRes, err := httpClient.Do(req)
	if err != nil {
		errorLogger.Printf("执行创建job:%s失败:%s", jobName, err.Error())
		responseDto.Message = "执行创建job失败"
		return responseDto
	}

	infoLogger.Printf("执行创建job:%s返回结果:%v", jobName, createRes)
	errorRes := createRes.Header.Get("X-Error")
	infoLogger.Printf("返回错误信息:%s", errorRes)
	if errorRes != "" && strings.Contains(errorRes, "A job already exists with the name  "+jobName) {
		responseDto.Message = "job名称已存在"
		return responseDto
	}
	if createRes.StatusCode != http.StatusFound {
		responseDto.Message = "执行创建job失败"
		return responseDto
	}
	infoLogger.Printf("执行创建job:%s成功", jobName)

	responseDto.Status = 200
	responseDto.Message = "成功"
	return responseDto
}

// StartRunPipelineJob ...
// @Title StartRunPipelineJob
// @Description start BuildPipelineJob
// @Param	lang		query 	string	true	"api result language type"
// @Param	body		body 	dto.StartRunPipelineJobRequestDto	true	""
// @Success 200 {object} dto.BaseResponseDto
// @Failure 300 {object} dto.BaseResponseDto
// @router /startRunPipelineJob [post]
func (c *JobController) StartRunPipelineJob() {
	lang := c.GetString("lang")
	infoLogger.Println("语言: ", lang)
	var requestDto dto.StartRunPipelineJobRequestDto
	var responseDto = dto.BaseResponseDto{300, ""}
	if err := json.Unmarshal(c.Ctx.Input.RequestBody, &requestDto); err != nil {
		errorLogger.Println(err)
		responseDto.Message = utils.GetI18nLang(lang, "requestParamIncorrectFormat")
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}
	infoLogger.Println("启动运行job请求参数: ", requestDto)
	jobName := requestDto.JobName
	if strings.TrimSpace(jobName) == "" {
		errorLogger.Println("job名称不能为空")
		responseDto.Message = "job名称不能为空"
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}

	const BaseUrl = "http://jenkins.poc.paas.com"
	buildUrl := BaseUrl + "/blue/rest/organizations/jenkins/pipelines/" + jobName + "/runs/"

	httpClient := &http.Client{
		Transport: &http.Transport{
			TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
		},
		Timeout: 10 * time.Second,
	}

	req, _ := http.NewRequest("POST", buildUrl, nil)
	req.Header.Set("Content-Type", "application/json;charset=utf-8")

	startRes, err := httpClient.Do(req)
	if err != nil {
		errorLogger.Println(err)
		errorLogger.Printf("启动运行job:%s失败:%s", jobName, err.Error())
		responseDto.Message = "启动运行job失败"
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}

	infoLogger.Printf("启动运行job:%s返回状态码:%s", jobName, startRes.Status)
	if startRes.StatusCode != http.StatusOK {
		responseDto.Message = "启动运行job失败"
		if startRes.StatusCode == http.StatusNotFound {
			responseDto.Message = "job不存在"
		}
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}
	infoLogger.Printf("启动运行job:%s成功", jobName)

	responseDto.Status = 200
	responseDto.Message = "启动运行成功"
	c.Data["json"] = responseDto
	c.ServeJSON()
}

// deletePipelineJob ...
// @Title deletePipelineJob
// @Description delete PipelineJob
// @Param	lang		query 	string	true	"api result language type"
// @Param	body		body 	dto.DeletePipelineJobRequestDto	true	""
// @Success 200 {object} dto.BaseResponseDto
// @Failure 300 {object} dto.BaseResponseDto
// @router /deletePipelineJob [post]
func (c *JobController) DeletePipelineJob() {
	lang := c.GetString("lang")
	infoLogger.Println("语言: ", lang)
	var requestDto dto.DeletePipelineJobRequestDto
	var responseDto = dto.BaseResponseDto{300, ""}
	if err := json.Unmarshal(c.Ctx.Input.RequestBody, &requestDto); err != nil {
		errorLogger.Println(err)
		responseDto.Message = utils.GetI18nLang(lang, "requestParamIncorrectFormat")
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}
	infoLogger.Println("删除job请求参数: ", requestDto)
	jobName := requestDto.JobName
	if strings.TrimSpace(jobName) == "" {
		errorLogger.Println("job名称不能为空")
		responseDto.Message = "job名称不能为空"
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}

	const BaseUrl = "http://jenkins.poc.paas.com"
	buildUrl := BaseUrl + "/job/" + jobName + "/doDelete"

	httpClient := &http.Client{
		Transport: &http.Transport{
			TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
		},
		Timeout: 10 * time.Second,
		CheckRedirect: func(req *http.Request, via []*http.Request) error {
			return http.ErrUseLastResponse
		},
	}

	req, _ := http.NewRequest("POST", buildUrl, nil)
	req.Header.Set("Content-Type", "application/x-www-form-urlencoded")

	deleteRes, err := httpClient.Do(req)
	if err != nil {
		errorLogger.Printf("执行删除job:%s失败:%s", jobName, err.Error())
		responseDto.Message = "执行删除job失败"
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}
	infoLogger.Printf("执行删除job:%s返回状态码:%s", jobName, deleteRes.Status)
	if deleteRes.StatusCode != http.StatusFound {
		responseDto.Message = "执行删除job失败"
		if deleteRes.StatusCode == http.StatusNotFound {
			responseDto.Message = "job不存在"
		}
		c.Data["json"] = responseDto
		c.ServeJSON()
		return
	}
	infoLogger.Printf("执行删除job:%s成功", jobName)

	responseDto.Status = 200
	responseDto.Message = "成功"
	c.Data["json"] = responseDto
	c.ServeJSON()
}
